/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
/* gdome-xml-str.c
 *
 * Copyright (C) 1999 Raph Levien <raph@acm.org>
 * Copyright (C) 2000 Mathieu Lacage <mathieu@gnu.org>
 * Copyright (C) 2001 Paolo Casarini <paolo@casarini.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <tree.h>
#include <parser.h>
#include <xmlmemory.h>
#include "gdome.h"
#include "gdome-xml-str.h"

void
gdome_xml_str_const_unref (GdomeDOMString *self) {
	g_free(self);
}

void
gdome_xml_str_unref_own (GdomeDOMString *self) {
	g_free (self->str);
	g_free (self);
}

void
gdome_xml_str_unref_xml (GdomeDOMString *self) {
  xmlFree (self->str);
  g_free (self);
}

GdomeDOMString *
gdome_xml_str_mkref (const gchar *str) {
	GdomeDOMString *ds;

	if (str == NULL)
		return NULL;
	ds = g_new (GdomeDOMString, 1);
  ds->refcnt = 1;
	ds->unref = gdome_xml_str_const_unref;
	ds->str = (gchar *)str;
	return ds;
}

GdomeDOMString *
gdome_xml_str_mkref_own (gchar *str) {
	GdomeDOMString *ds;

	if (str == NULL)
		return NULL;
	ds = g_new (GdomeDOMString, 1);
	ds->refcnt = 1;
	ds->unref = gdome_xml_str_unref_own;
  ds->str = str;
	return ds;
}

GdomeDOMString *
gdome_xml_str_mkref_xml (xmlChar *str) {
  GdomeDOMString *ds;

	if (str == NULL)
		return NULL;
	ds = g_new (GdomeDOMString, 1);
  ds->refcnt = 1;
	ds->unref = gdome_xml_str_unref_xml;
	ds->str = str;
	return ds;
}

GdomeDOMString *
gdome_xml_str_mkref_dup (gchar *str) {
	GdomeDOMString *ds;

	if (str == NULL)
		return NULL;
	ds = g_new (GdomeDOMString, 1);
	ds->refcnt = 1;
	ds->unref = gdome_xml_str_unref_own;
  ds->str = g_strdup(str);
	return ds;
}

void
gdome_xml_str_ref (GdomeDOMString *self) {
	self->refcnt++;
}

void
gdome_xml_str_unref (GdomeDOMString *self) {
	self->refcnt--;

	if(self->refcnt == 0)
		self->unref (self);
}

/**
 * gdome_xml_str_equal:
 * @self the DOMString ref
 * @str the DOMString to be compared
 *
 * Returns TRUE if the strings are equal, FALSE otherwise.
 */
GdomeBoolean
gdome_xml_str_equal(GdomeDOMString *self, GdomeDOMString *str) {
	if(xmlStrEqual((xmlChar *)self->str, (xmlChar *)str->str))
		return TRUE;
	else
    return FALSE;
}


/* ------------------ OLD FUNCTIONS TO BE REMOVED ----------------*/
GdomeDOMString *
gdome_xml_str_mkref_nop (const char *str)
{
  GdomeDOMString *ds;
	
  if (str == NULL)
    return NULL;
  ds = g_new (GdomeDOMString, 1);
  ds->unref = gdome_xml_str_unref_nop;
  ds->str = (char *)str;
  return ds;
}
void
gdome_xml_str_unref_nop (GdomeDOMString *self)
{
	int i = 0;
	/* do nothing */

}

/* Make a string reference, and take ownership of the memory, to be
   freed with xmlFree(). This is useful for strings allocated by
   libxml. */
GdomeDOMString *
gdome_xml_str_mkref_xmlfree (char *str)
{
  GdomeDOMString *ds;

  if (str == NULL)
    return NULL;
  ds = g_new (GdomeDOMString, 1);
  ds->unref = gdome_xml_str_unref_xmlfree;
  ds->str = str;
  return ds;
}

void
gdome_xml_str_unref_xmlfree (GdomeDOMString *self)
{
  xmlFree (self->str);
  g_free (self);
}

void
gdome_xml_str_unref1 (GdomeDOMString *self)
{
	g_free(self);
}
