/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
/* test-document.c
 *
 * Copyright (C) 2001 Paolo Casarini <paolo@casarini.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

#include <glib.h>
#include <stdio.h>
#include <parser.h>
#include <gdome.h>
#include <gdome-xml-str.h>

void
dot() {
	printf(".");
	fflush(stdout);
}

gboolean
test_document1 (GdomeDocument *doc) {
	GdomeElement *root, *el1, *el2;
	GdomeDocumentFragment *df;
  GdomeText *txt;
  GdomeCDATASection *cds;
	GdomeComment *cmt;
	GdomeProcessingInstruction *pi;
	GdomeAttr *attr1, *attr2;
	GdomeException exc = 0;
	GdomeDOMString *tstr1, *tstr2;
	gboolean ret = TRUE;

	/* Test Documet.documentElement */
	root = doc->vtab->documentElement (doc, &exc);
	if (root == NULL)
		fprintf (stderr, "\nDocument.documentElement, NULL"), ret = FALSE;
	else if (!xmlStrEqual((root->vtab->tagName (root, &exc))->str, "TEST"))
		fprintf (stderr, "\nDocument.documentElement, wrong"), ret = FALSE;
	dot();

	/* Test Document.createElement */
	tstr1 = gdome_xml_str_mkref ("EL1");
	el1 = doc->vtab->createElement (doc, tstr1, &exc);
	if (el1 == NULL)
		fprintf (stderr, "\nDocument.createElement, NULL"), ret = FALSE;
	else if (el1->vtab->super.nodeType ((GdomeNode *)el1, &exc) != XML_ELEMENT_NODE)
		fprintf (stderr, "\nDocument.createElement, wrong nodeType"), ret = FALSE;
	else if (el1->vtab->super.ownerDocument ((GdomeNode *)el1, &exc) != doc)
		fprintf (stderr, "\nDocument.createElement, wrong ownerDocument"), ret = FALSE;
	else if (!xmlStrEqual((el1->vtab->tagName (el1, &exc))->str, "EL1"))
		fprintf (stderr, "\nDocument.createElement, wrong tagName"), ret = FALSE;
	tstr1->unref(tstr1);
  dot();

	/* Test Document.createElementNS */
	tstr1 = gdome_xml_str_mkref ("tns:EL2");
	tstr2 = gdome_xml_str_mkref ("urn:test.tst");
	el2 = doc->vtab->createElementNS (doc, tstr2, tstr1, &exc);
	if (el2 == NULL)
		fprintf (stderr, "\nDocument.createElementNS, NULL"), ret = FALSE;
	else if (el2->vtab->super.nodeType ((GdomeNode *)el2, &exc) != XML_ELEMENT_NODE)
		fprintf (stderr, "\nDocument.createElement, wrong nodeType"), ret = FALSE;
	else if (el2->vtab->super.ownerDocument ((GdomeNode *)el2, &exc) != doc)
		fprintf (stderr, "\nDocument.createElementNS, wrong ownerElement"), ret = FALSE;
	else if (!xmlStrEqual((el2->vtab->tagName (el2, &exc))->str, "tns:EL2"))
		fprintf (stderr, "\nDocument.createElement, wrong tagName"), ret = FALSE;
	else if (!xmlStrEqual((el2->vtab->super.localName ((GdomeNode *)el2, &exc))->str, "EL2"))
		fprintf (stderr, "\nDocument.createElement, wrong localName"), ret = FALSE;
	else if (!xmlStrEqual((el2->vtab->super.namespaceURI ((GdomeNode *)el2, &exc))->str, "urn:test.tst"))
		fprintf (stderr, "\nDocument.createElement, wrong namespaceURI"), ret = FALSE;
	tstr1->unref(tstr1);
	tstr2->unref(tstr2);
	dot();

  /* Test Document.createDocumentFragment */
	df = doc->vtab->createDocumentFragment (doc, &exc);
	if (df == NULL)
		fprintf (stderr, "\nDocument.createDocumentFragment, NULL"), ret = FALSE;
	else if (df->vtab->super.nodeType ((GdomeNode *)df, &exc) != XML_DOCUMENT_FRAG_NODE)
		fprintf (stderr, "\nDocument.createDocumentFragment, wrong nodeType"), ret = FALSE;
	else if (df->vtab->super.ownerDocument ((GdomeNode *)df, &exc) != doc)
		fprintf (stderr, "\nDocument.createDocumentFragment, wrong ownerDocument"), ret = FALSE;
	else if (!xmlStrEqual((df->vtab->super.nodeName ((GdomeNode *)df, &exc))->str, "#document-fragment"))
		fprintf (stderr, "\nDocument.createDocumentFragment, wrong nodeName"), ret = FALSE;
	dot();

  /* Test Document.createTextNode */
	tstr1 = gdome_xml_str_mkref ("<Test>Text Test</Test>");
	txt = doc->vtab->createTextNode (doc, tstr1, &exc);
	if (txt == NULL)
		fprintf (stderr, "\nDocument.createTextNode, NULL"), ret = FALSE;
	else if (txt->vtab->super.super.nodeType ((GdomeNode *)txt, &exc) != XML_TEXT_NODE)
		fprintf (stderr, "\nDocument.createTextNode, wrong nodeType"), ret = FALSE;
	else if (txt->vtab->super.super.ownerDocument ((GdomeNode *)txt, &exc) != doc)
		fprintf (stderr, "\nDocument.createTextNode, wrong ownerDocument"), ret = FALSE;
	else if (!xmlStrEqual((txt->vtab->super.super.nodeName ((GdomeNode *)txt, &exc))->str, "#text"))
		fprintf (stderr, "\nDocument.createTextNode, wrong nodeName"), ret = FALSE;
	else if (!xmlStrEqual((txt->vtab->super.super.nodeValue ((GdomeNode *)txt, &exc))->str, "<Test>Text Test</Test>"))
		fprintf (stderr, "\nDocument.createTextNode, wrong nodeValue"), ret = FALSE;
	tstr1->unref(tstr1);
	dot();

  /* Test Document.createCDATASection */
	tstr1 = gdome_xml_str_mkref ("<Test>Text Test</Test>");
	cds = doc->vtab->createCDATASection (doc, tstr1, &exc);
	if (cds == NULL)
		fprintf (stderr, "\nDocument.createCDATASection, NULL"), ret = FALSE;
	else if (cds->vtab->super.super.super.nodeType ((GdomeNode *)cds, &exc) != XML_CDATA_SECTION_NODE)
		fprintf (stderr, "\nDocument.createCDATASection, wrong nodeType"), ret = FALSE;
	else if (cds->vtab->super.super.super.ownerDocument ((GdomeNode *)cds, &exc) != doc)
		fprintf (stderr, "\nDocument.createCDATASection, wrong ownerDocument"), ret = FALSE;
	else if (!xmlStrEqual((cds->vtab->super.super.super.nodeName ((GdomeNode *)cds, &exc))->str, "#cdata-section"))
		fprintf (stderr, "\nDocument.createCDATASection, wrong nodeName"), ret = FALSE;
	else if (!xmlStrEqual((cds->vtab->super.super.super.nodeValue ((GdomeNode *)cds, &exc))->str, "<Test>Text Test</Test>"))
		fprintf (stderr, "\nDocument.createCDATASection, wrong nodeValue"), ret = FALSE;
	tstr1->unref(tstr1);
	dot();

  /* Test Document.createComment */
	tstr1 = gdome_xml_str_mkref ("dududu dadada");
	cmt = doc->vtab->createComment (doc, tstr1, &exc);
	if (cmt == NULL)
		fprintf (stderr, "\nDocument.createComment, NULL"), ret = FALSE;
	else if (cmt->vtab->super.super.nodeType ((GdomeNode *)cmt, &exc) != XML_COMMENT_NODE)
		fprintf (stderr, "\nDocument.createComment, wrong nodeType"), ret = FALSE;
	else if (cmt->vtab->super.super.ownerDocument ((GdomeNode *)cmt, &exc) != doc)
		fprintf (stderr, "\nDocument.createComment, wrong ownerDocument"), ret = FALSE;
	else if (!xmlStrEqual((cmt->vtab->super.super.nodeName ((GdomeNode *)cmt, &exc))->str, "#comment"))
		fprintf (stderr, "\nDocument.createComment, wrong nodeName"), ret = FALSE;
	else if (!xmlStrEqual((cmt->vtab->super.super.nodeValue ((GdomeNode *)cmt, &exc))->str, "dududu dadada"))
		fprintf (stderr, "\nDocument.createComment, wrong nodeValue"), ret = FALSE;
	tstr1->unref(tstr1);
	dot();

  /* Test Document.createProcessingInstruction */
	tstr1 = gdome_xml_str_mkref ("sqlprocessor");
	tstr2 = gdome_xml_str_mkref ("SELECT * FROM blah");
	pi = doc->vtab->createProcessingInstruction (doc, tstr1, tstr2, &exc);
	if (pi == NULL)
		fprintf (stderr, "\nDocument.createProcessingInstruction, NULL"), ret = FALSE;
	else if (pi->vtab->super.nodeType ((GdomeNode *)pi, &exc) != XML_PI_NODE)
		fprintf (stderr, "\nDocument.createProcessingInstruction, wrong nodeType"), ret = FALSE;
	else if (pi->vtab->super.ownerDocument ((GdomeNode *)pi, &exc) != doc)
		fprintf (stderr, "\nDocument.createProcessingInstruction, wrong ownerDocument"), ret = FALSE;
	else if (!xmlStrEqual((pi->vtab->super.nodeName ((GdomeNode *)pi, &exc))->str, "sqlprocessor"))
		fprintf (stderr, "\nDocument.createProcessingInstruction, wrong nodeName"), ret = FALSE;
	else if (!xmlStrEqual((pi->vtab->super.nodeValue ((GdomeNode *)pi, &exc))->str, "SELECT * FROM blah"))
		fprintf (stderr, "\nDocument.createProcessingInstruction, wrong nodeValue"), ret = FALSE;
	tstr1->unref(tstr1);
	tstr2->unref(tstr2);
	dot();

  /* Test Document.createAttribute */
	tstr1 = gdome_xml_str_mkref ("ATTR1");
	attr1 = doc->vtab->createAttribute (doc, tstr1, &exc);
	if (attr1 == NULL)
		fprintf (stderr, "\nDocument.createAttribute, NULL"), ret = FALSE;
	else if (attr1->vtab->super.nodeType ((GdomeNode *)attr1, &exc) != XML_ATTRIBUTE_NODE)
		fprintf (stderr, "\nDocument.createAttribute, wrong nodeType"), ret = FALSE;
	else if (attr1->vtab->super.ownerDocument ((GdomeNode *)attr1, &exc) != doc)
		fprintf (stderr, "\nDocument.createAttribute, wrong ownerDocument"), ret = FALSE;
	else if (!xmlStrEqual((attr1->vtab->name (attr1, &exc))->str, "ATTR1"))
		fprintf (stderr, "\nDocument.createAttribute, wrong name"), ret = FALSE;
	else if (!xmlStrEqual((attr1->vtab->value (attr1, &exc))->str, ""))
		fprintf (stderr, "\nDocument.createAttribute, wrong value"), ret = FALSE;
	tstr1->unref(tstr1);
	dot();

  /* Test Document.createAttributeNS */
	tstr1 = gdome_xml_str_mkref ("tns:ATTR2");
	tstr2 = gdome_xml_str_mkref ("urn:test.tst");
	attr2 = doc->vtab->createAttributeNS (doc, tstr2, tstr1, &exc);
	if (attr1 == NULL)
		fprintf (stderr, "\nDocument.createAttributeNS, NULL"), ret = FALSE;
	else if (attr2->vtab->super.nodeType ((GdomeNode *)attr2, &exc) != XML_ATTRIBUTE_NODE)
		fprintf (stderr, "\nDocument.createAttributeNS, wrong nodeType"), ret = FALSE;
	else if (attr2->vtab->super.ownerDocument ((GdomeNode *)attr2, &exc) != doc)
		fprintf (stderr, "\nDocument.createAttributeNS, wrong ownerDocument"), ret = FALSE;
	else if (!xmlStrEqual((attr2->vtab->name (attr2, &exc))->str, "tns:ATTR2"))
		fprintf (stderr, "\nDocument.createAttributeNS, wrong name"), ret = FALSE;
	else if (!xmlStrEqual((attr2->vtab->super.localName ((GdomeNode *)attr2, &exc))->str, "ATTR2"))
		fprintf (stderr, "\nDocument.createAttributeNS, wrong localName"), ret = FALSE;
	else if (!xmlStrEqual((attr2->vtab->super.namespaceURI ((GdomeNode *)attr2, &exc))->str, "urn:test.tst"))
		fprintf (stderr, "\nDocument.createAttributeNS, wrong namespaceURI"), ret = FALSE;
	else if (!xmlStrEqual((attr2->vtab->value (attr2, &exc))->str, ""))
		fprintf (stderr, "\nDocument.createAttributeNS, wrong value"), ret = FALSE;
	tstr1->unref(tstr1);
	tstr2->unref(tstr2);
	dot();

	/* Now I build a simple tree with the nodes created */
	root->vtab->setAttributeNode (root, attr1, &exc);
	el1->vtab->setAttributeNode (el1, attr2, &exc);
	root->vtab->super.appendChild ((GdomeNode *)root,(GdomeNode *) el1, &exc);
	root->vtab->super.appendChild ((GdomeNode *)root,(GdomeNode *) pi, &exc);
	el2->vtab->super.appendChild ((GdomeNode *)el2,(GdomeNode *) txt, &exc);
	el2->vtab->super.appendChild ((GdomeNode *)el2,(GdomeNode *) cds, &exc);
	el2->vtab->super.appendChild ((GdomeNode *)el2,(GdomeNode *) cmt, &exc);
	root->vtab->super.appendChild ((GdomeNode *)root,(GdomeNode *) el2, &exc);
	dot();

	printf ("test_document1\n");
	return ret;
}

gboolean
test_document2 (GdomeDocument *doc) {
	GdomeElement *els[9], *root;
	GdomeNode *tel;
	GdomeNodeList *nl;
	GdomeException exc = 0;
	GdomeDOMString *tstr1;
	gboolean ret = TRUE;
	int i;

	/* Test Document.getElementById*/
	for(i=0; i<9; i++) {
		tstr1 = gdome_xml_str_mkref_own(g_strdup_printf("%d",i));
		els[i] = doc->vtab->getElementById(doc, tstr1, &exc);
		if(els[i] == NULL)
			fprintf (stderr, "\nDocument.getElementById(\"%s\"), NULL",tstr1->str), ret = FALSE;
		tstr1->unref(tstr1);
	}
	dot();

  /* Test Document.getElementByTagName */
	tstr1 = gdome_xml_str_mkref("NODE");
	nl = doc->vtab->getElementsByTagName(doc, tstr1, &exc);
	if(nl == NULL)
		fprintf (stderr, "\nDocument.getElementByTagName(\"%s\"), NULL",tstr1->str), ret = FALSE;
	if(nl->vtab->length(nl, &exc) != 9)
		fprintf (stderr, "\nDocument.getElementByTagName(\"%s\"), wrong length",tstr1->str), ret = FALSE;
	for(i=0; i<9; i++) {
		tel = nl->vtab->item(nl, (unsigned long)i, &exc);
		if (tel != (GdomeNode *)els[i])
			fprintf (stderr, "\nDocument.getElementByTagName(\"%s\"), wrong %d-th item",tstr1->str,i), ret = FALSE;
		if (tel != NULL)
			gdome_n_unref (tel, &exc);
	}
	tstr1->unref(tstr1);
	dot();

	/* Is NodeList live? */
	root = doc->vtab->documentElement (doc, &exc);
	root->vtab->super.removeChild ((GdomeNode *)root, (GdomeNode *)els[3], &exc);
	if(nl->vtab->item(nl, 3L, &exc) != (GdomeNode *)els[6])
		fprintf (stderr, "\nNODELIST IS NOT LIVE!!"), ret = FALSE;
	dot();

	printf ("test_document2\n");
	return ret;
}

gboolean
test_document3 (GdomeDocument *doc) {
	GdomeElement *els[4], *root;
	GdomeNode *tel;
	GdomeNodeList *nl;
	GdomeException exc = 0;
	GdomeDOMString *tstr1, *tstr2;
	gboolean ret = TRUE;
	int i;

	/* Test Document.getElementById*/
	for(i=1; i<9; i+=2) {
		tstr1 = gdome_xml_str_mkref_own(g_strdup_printf("%d",i));
		els[i/2] = doc->vtab->getElementById(doc, tstr1, &exc);
		if(els[i/2] == NULL)
			fprintf (stderr, "\nDocument.getElementById(\"%s\"), NULL",tstr1->str), ret = FALSE;
		tstr1->unref(tstr1);
	}
	dot();

  /* Test Document.getElementByTagNameNS */
	tstr1 = gdome_xml_str_mkref("NODE");
	tstr2 = gdome_xml_str_mkref("urn:test.tst");
	nl = doc->vtab->getElementsByTagNameNS(doc, tstr2, tstr1, &exc);
	if(nl == NULL)
		fprintf (stderr, "\nDocument.getElementByTagNameNS(\"%s\",\"%s\"), NULL",tstr2->str,tstr1->str), ret = FALSE;
	if(nl->vtab->length(nl, &exc) != 4)
		fprintf (stderr, "\nDocument.getElementByTagNameNS(\"%s\",\"%s\"), wrong length",tstr2->str,tstr1->str), ret = FALSE;
	for(i=0; i<4; i++) {
		tel = nl->vtab->item(nl, (unsigned long)i, &exc);
		if (tel != (GdomeNode *)els[i])
			fprintf (stderr, "\nDocument.getElementByTagName(\"%s\",\"%s\"), wrong %d-th item",tstr2->str,tstr1->str,i), ret = FALSE;
		if (tel != NULL)
			gdome_n_unref (tel, &exc);
	}
	tstr1->unref(tstr1);
	tstr2->unref(tstr2);
	dot();

	/* Is NodeList live? */
	root = doc->vtab->documentElement (doc, &exc);
	root->vtab->super.removeChild ((GdomeNode *)root, (GdomeNode *)els[1], &exc);
	if(nl->vtab->item(nl, 1L, &exc) != (GdomeNode *)els[3])
		fprintf (stderr, "\nNODELIST IS NOT LIVE!!"), ret = FALSE;
	dot();

	printf ("test_document3\n");
	return ret;
}

int
main (int argc, char **argv)
{
	GdomeDOMImplementation *domImpl = NULL;
	GdomeDocument *domdoc = NULL;
	GdomeDOMString *str = NULL;
	GdomeException exc = 0;
	gboolean ret;

	domImpl = gdome_DOMImplementation_mkref();
	str = gdome_xml_str_mkref ("TEST");
	domdoc = domImpl->vtab->createDocument (domImpl, NULL, str, NULL, &exc);

	ret = test_document1(domdoc);
	domImpl->vtab->saveFile(domImpl, "test-document1.xml", domdoc, &exc);
  domImpl->vtab->freeDoc(domImpl, domdoc, &exc);

	domdoc = domImpl->vtab->parseFile(domImpl, "test-document2.xml", &exc);
  ret = test_document2(domdoc);
  domImpl->vtab->freeDoc(domImpl, domdoc, &exc);

	domdoc = domImpl->vtab->parseFile(domImpl, "test-document3.xml", &exc);
	ret = test_document3(domdoc);
  domImpl->vtab->freeDoc(domImpl, domdoc, &exc);

	if(ret)
		return 0;
	else
		return -1;
}
