/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
/* test-dtd.c
 *
 * Copyright (C) 2001 Paolo Casarini <paolo@casarini.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

#include <glib.h>
#include <stdio.h>
#include <string.h>
#include <parser.h>
#include <gdome.h>
#include <gdome-xml-str.h>

void
dot() {
	printf(".");
	fflush(stdout);
}

gboolean
test_dtd (GdomeDocument *doc)
{
	GdomeDocumentType *dt;
  GdomeNamedNodeMap *ents, *nots;
  GdomeDOMString *str;
	GdomeException exc;
	GdomeEntity *ent;
  GdomeNotation *not;
	gboolean ret = TRUE;

	dt = doc->vtab->doctype (doc, &exc);

	/* Test DocumentType.name */
	str = dt->vtab->name (dt, &exc);
	if (str == NULL)
		fprintf (stderr, "\nDocumentType.name, NULL"), ret = FALSE;
  else if (ret && !xmlStrEqual (str->str, "TEST-DTD"))
		fprintf (stderr, "\nDocumentType.name, wrong"), ret = FALSE;
  dot();

  /* Test DocumentType.publicId */
	str = dt->vtab->publicId (dt, &exc);
	if (str != NULL)
		fprintf (stderr, "\nDocumentType.publicId, wrong"), ret = FALSE;
  dot();

	/* Test DocumentType.systemId */
	str = dt->vtab->systemId (dt, &exc);
	if (str == NULL)
		fprintf (stderr, "\nDocumentType.systemId, NULL"), ret = FALSE;
  else if (ret && !xmlStrEqual (str->str, "test-dtd.dtd"))
		fprintf (stderr, "\nDocumentType.systemId, wrong"), ret = FALSE;
	dot();

	/* Test DocumentType.entities */
	ents = dt->vtab->entities (dt, &exc);
  if (ents == NULL)
		fprintf (stderr, "\nDocumentType.entities, NULL"), ret = FALSE;
  else if (ret && ents->vtab->length (ents, &exc) != 5)
		fprintf (stderr, "\nDocumentType.entities, wrong length"), ret = FALSE;
  dot();

	/* Test DocumentType.notations */
	nots = dt->vtab->notations (dt, &exc);
  if (ents == NULL)
		fprintf (stderr, "\nDocumentType.notations, NULL"), ret = FALSE;
  else if (ret && ents->vtab->length (ents, &exc) != 5)
		fprintf (stderr, "\nDocumentType.notations, wrong length"), ret = FALSE;
  dot();

	printf ("test_dtd\n");

	/* Test Parsed Entity */
  ent = (GdomeEntity *)ents->vtab->getNamedItem (ents, gdome_xml_str_mkref ("FOO1"), &exc);
	if (ent == NULL)
		fprintf (stderr, "\nNamedNodeMap.getNamedItem(\"FOO1\"), NULL"), ret = FALSE;
  else if (ret && !xmlStrEqual ((ent->vtab->super.nodeName ((GdomeNode *)ent, &exc))->str, "FOO1"))
		fprintf (stderr, "\nEntity.nodeName(), (parsed) FOO1 wrong nodeName"), ret = FALSE;
  else if (ret && ent->vtab->publicId (ent, &exc) != NULL)
		fprintf (stderr, "\nEntity.publicId(), (parsed) FOO1 NOT NULL"), ret = FALSE;
  else if (ret && ent->vtab->systemId (ent, &exc) != NULL)
		fprintf (stderr, "\nEntity.systemId(), (parsed) FOO1 NOT NULL"), ret = FALSE;
  else if (ret && ent->vtab->notationName (ent, &exc) != NULL)
		fprintf (stderr, "\nEntity.notationName(), (parsed) FOO1 NOT NULL"), ret = FALSE;
	if (ret)
		gdome_n_unref ((GdomeNode *)ent, &exc);
  dot();


	/* Test Unparsed Entity */
	ent = (GdomeEntity *)ents->vtab->getNamedItem (ents, gdome_xml_str_mkref ("FOO2"), &exc);
	if (ent == NULL)
		fprintf (stderr, "\nNamedNodeMap.getNamedItem(\"FOO2\"), NULL"), ret = FALSE;
  else if (ret && !xmlStrEqual ((ent->vtab->super.nodeName ((GdomeNode *)ent, &exc))->str, "FOO2"))
		fprintf (stderr, "\nEntity.nodeName(), (unparsed) FOO2 wrong"), ret = FALSE;
  else if (ret && ent->vtab->publicId (ent, &exc) != NULL)
		fprintf (stderr, "\nEntity.publicId(), (unparsed) FOO2 wrong"), ret = FALSE;
  else if (ret && !xmlStrEqual ((ent->vtab->systemId (ent, &exc))->str, "file.type2"))
		fprintf (stderr, "\nEntity.systemId(), (unparsed) FOO2 wrong"), ret = FALSE;
  else if (ret && !xmlStrEqual ((ent->vtab->notationName (ent, &exc))->str, "type2"))
		fprintf (stderr, "\nEntity.notationName(), (unparsed) FOO2 wrong"), ret = FALSE;
	if (ret)
		gdome_n_unref ((GdomeNode *)ent, &exc);
  dot();

	printf ("test_entity\n");

	/* Test Notation */
  not = (GdomeNotation *)ents->vtab->getNamedItem (nots, gdome_xml_str_mkref ("type1"), &exc);
	if (not == NULL)
		fprintf (stderr, "\nNamedNodeMap.getNamedItem(\"type1\"), NULL"), ret = FALSE;
  else if (ret && !xmlStrEqual ((not->vtab->super.nodeName ((GdomeNode *)not, &exc))->str, "type1"))
		fprintf (stderr, "\nNotation.nodeName(), wrong nodeName"), ret = FALSE;
	else if (ret && not->vtab->publicId (not, &exc) != NULL)
		fprintf (stderr, "\nNotation.publicId(), NOT NULL"), ret = FALSE;
  else if (ret && !xmlStrEqual ((not->vtab->systemId (not, &exc))->str, "program1"))
		fprintf (stderr, "\nNotation.systemId(), wrong"), ret = FALSE;
	if (ret)
		gdome_n_unref ((GdomeNode *)not, &exc);
	dot();

  printf ("test_notation\n");

  dt->vtab->super.unref (dt, &exc);

  return ret;
}

int
main (int argc, char **argv)
{
	GdomeDOMImplementation *domImpl = NULL;
	GdomeDocument *domdoc = NULL;
	GdomeException exc = 0;
	gboolean ret;

	domImpl = gdome_DOMImplementation_mkref();

  domdoc = gdome_DOMImplementation_validateFile(domImpl, "test-dtd.xml", &exc);
  ret = test_dtd(domdoc);
  domImpl->vtab->freeDoc(domImpl, domdoc, &exc);

	if(ret)
		return 0;
	else
		return -1;
}
