/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
/* test-element.c
 *
 * Copyright (C) 2001 Paolo Casarini <paolo@casarini.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

#include <gdome.h>

void dot() {
  printf(".");
  fflush(stdout);
}

gboolean test_el(GdomeElement *el) {
	GdomeNamedNodeMap *nnm;
	GdomeAttr *attr;
	GdomeAttr *attrNS;
  GdomeAttr *attrDef;

	GdomeDOMString *attr_name;
  GdomeDOMString *attr_value;
  GdomeDOMString *attr_URI;
  GdomeDOMString *temp_str;
  GdomeException exc;
  gboolean ret = TRUE;

  /* test Element::tagName */
	temp_str = gdome_el_tagName(el, &exc);
	if(!gdome_str_equal(temp_str, gdome_str_mkref("TEST")))
		fprintf(stderr,"\nElement.tagName(), wrong"), ret = FALSE;
  dot();

	/* test Element::attributes */
	nnm = gdome_el_attributes(el, &exc);
	if(nnm == NULL)
		fprintf(stderr,"\nElement.attributes, NULL"), ret = FALSE;
  else
		gdome_nnm_unref(nnm, &exc);
	dot();

	/* test Element::getAttributeNode */
	attr_name = gdome_str_mkref("XXXX");
	attr = gdome_el_getAttributeNode(el, attr_name, &exc);
	if(attr != NULL)
		fprintf(stderr,"\nElement.getAttributeNode(\"%s\"), NOT NULL",attr_name->str), ret = FALSE;
	attr_name = gdome_str_mkref("FOO1");
	attr = gdome_el_getAttributeNode(el, attr_name, &exc);
	if(attr == NULL)
		fprintf(stderr,"\nElement.getAttributeNode(\"%s\"), NULL",attr_name->str), ret = FALSE;
	else if(ret && !gdome_str_equal(gdome_a_nodeName(attr, &exc), attr_name))
		fprintf(stderr,"\nElement.getAttributeNode(\"%s\"), wrong",attr_name->str), ret = FALSE;
  dot();

	/* test Element::getAttributeNodeNS */
  attr_name = gdome_str_mkref("CIPPO2");
  attr_URI = gdome_str_mkref("urn:xxxx.xxxx.xx");
  attrNS = gdome_el_getAttributeNodeNS(el, attr_URI, attr_name, &exc);
	if(attrNS != NULL)
		fprintf(stderr,"\nElement.getAttributeNodeNS(\"%s\",\"%s\"), NOT NULL",attr_URI->str,attr_name->str), ret = FALSE;
  attr_name = gdome_str_mkref("XXXXX");
  attr_URI = gdome_str_mkref("urn:cips.ciak.uk");
  attrNS = gdome_el_getAttributeNodeNS(el, attr_URI, attr_name, &exc);
	if(attrNS != NULL)
		fprintf(stderr,"\nElement.getAttributeNodeNS(\"%s\",\"%s\"), NOT NULL",attr_URI->str,attr_name->str), ret = FALSE;
  attr_name = gdome_str_mkref("CIPPO2");
  attr_URI = gdome_str_mkref("urn:cips.ciak.uk");
  attrNS = gdome_el_getAttributeNodeNS(el, attr_URI, attr_name, &exc);
	if(attrNS == NULL)
		fprintf(stderr,"\nElement.getAttributeNodeNS(\"%s\",\"%s\"), NULL",attr_URI->str,attr_name->str), ret = FALSE;
  else if(ret && !gdome_str_equal(gdome_a_nodeName(attrNS,&exc), gdome_str_mkref("pippo:CIPPO2")))
		fprintf(stderr,"\nElement.getAttributeNodeNS(\"%s\",\"%s\"), wrong",attr_URI->str,attr_name->str), ret = FALSE;
	dot();

	/* test ELement::removeAttributeNode */
  attr_name = gdome_str_mkref("FOO1");
	attr = gdome_el_removeAttributeNode(el, attr, &exc);
	if(attr == NULL)
		fprintf(stderr,"\nElement.removeAttributeNode(attr), NULL"), ret = FALSE;
	else if(ret && !gdome_str_equal(gdome_a_nodeName(attr,&exc), attr_name))
		fprintf(stderr,"\nElement.removeAttribute(attr), wrong"), ret = FALSE;
	else if(ret && gdome_el_getAttributeNode(el, attr_name, &exc) != NULL)
		fprintf(stderr,"\nElement.removeAttributeNode(attr), error"), ret = FALSE;
  attr_name =  gdome_str_mkref("CIPPO2");
  attr_URI = gdome_str_mkref("urn:cips.ciak.uk");
	attrNS = gdome_el_removeAttributeNode(el, attrNS, &exc);
	if(attr == NULL)
		fprintf(stderr,"\nElement.removeAttributeNode(attrNS), NULL"), ret = FALSE;
  else if(ret && !gdome_str_equal(gdome_a_nodeName(attrNS,&exc), gdome_str_mkref("pippo:CIPPO2")))
		fprintf(stderr,"\nElement.removeAttribute(attrNS), wrong"), ret = FALSE;
	else if(ret && gdome_el_getAttributeNodeNS(el, attr_URI, attr_name, &exc) != NULL)
		fprintf(stderr,"\nElement.removeAttributeNode(attrNS), error"), ret = FALSE;
	attr_name = gdome_str_mkref("FOO2");
  temp_str = gdome_str_mkref("ciccia2");
  attrDef = gdome_el_getAttributeNode(el, attr_name, &exc);
	attrDef = gdome_el_removeAttributeNode(el, attrDef, &exc);
	if(attrDef == NULL)
		fprintf(stderr,"\nElement.removeAttributeNode(attrDef), NULL"), ret = FALSE;
	else if(ret && !gdome_str_equal(gdome_a_nodeName(attrDef,&exc), attr_name))
		fprintf(stderr,"\nElement.removeAttribute(attrDef), wrong");
	else if(ret && (attrDef = gdome_el_getAttributeNode(el, attr_name, &exc)) == NULL)
		fprintf(stderr,"\nElement.removeAttributeNode(attrDef), error1"), ret = FALSE;
	else if(ret && (!gdome_str_equal(gdome_a_nodeName(attrDef,&exc), attr_name) ||
                  !gdome_str_equal(gdome_a_nodeValue(attrDef,&exc), temp_str)))
    fprintf(stderr,"\nElement.removeAttribute(attrDef), error2"), ret = FALSE;
	dot();

	/* test Element::setAttributeNode */
  attr_name = gdome_str_mkref("FOO1");
	attr = gdome_el_setAttributeNode(el, attr, &exc);
  if(attr != NULL)
		fprintf(stderr,"\nElement.setAttributeNode(attr), NOT NULL"), ret = FALSE;
  else if(ret && (attr = gdome_el_getAttributeNode(el, attr_name, &exc)) == NULL)
		fprintf(stderr,"\nElement.setAttributeNode(attr), error1"), ret = FALSE;
  else if(ret && !gdome_str_equal(gdome_a_nodeName(attr,&exc), attr_name))
		fprintf(stderr,"\nElement.setAttributeNode(attr), error2"), ret = FALSE;
  dot();

	/* test Element::setAttributeNodeNS */
  attr_name = gdome_str_mkref("CIPPO2");
  attr_URI = gdome_str_mkref("urn:cips.ciak.uk");
	attrNS = gdome_el_setAttributeNodeNS(el, attrNS, &exc);
  if(attrNS != NULL)
		fprintf(stderr,"\nElement.setAttributeNodeNS(attrNS), NOT NULL"), ret = FALSE;
  else if(ret && (attrNS = gdome_el_getAttributeNodeNS(el, attr_URI, attr_name, &exc)) == NULL)
		fprintf(stderr,"\nElement::setAttributeNodeNS(attrNS), error1"), ret = FALSE;
  else if(ret && !gdome_str_equal(gdome_a_nodeName(attrNS,&exc), gdome_str_mkref("pippo:CIPPO2")))
		fprintf(stderr,"\nElement.setAttributeNodeNS(attrNS), error2"), ret = FALSE;
  dot();

	/* test Element::getAttribute */
	attr_name = gdome_str_mkref("FOO3");
	temp_str = gdome_el_getAttribute(el, attr_name, &exc);
  if(temp_str == NULL)
		fprintf(stderr,"\nElement.getAttribute(\"%s\"), NULL", attr_name->str), ret = FALSE;
  else if(ret && !gdome_str_equal(temp_str,gdome_str_mkref("bar3")))
		fprintf(stderr,"\nElement.getAttribute(\"%s\"), wrong", attr_name->str), ret = FALSE;
	attr_name = gdome_str_mkref("XXXX");
	temp_str = gdome_el_getAttribute(el, attr_name, &exc), ret = FALSE;
  if(temp_str != NULL)
		fprintf(stderr,"\nElement.getAttribute(\"%s\"), NOT NULL", attr_name->str), ret = FALSE;
  dot();

	/* test Element::getAttributeNS */
	attr_name = gdome_str_mkref("CIPPO3");
  attr_URI = gdome_str_mkref("urn:cips.ciak.uk");
	temp_str = gdome_el_getAttributeNS(el, attr_URI, attr_name, &exc);
  if(temp_str == NULL)
		fprintf(stderr,"\nElement.getAttributeNS(\"%s\",\"%s\"), NULL", attr_URI->str,attr_name->str), ret = FALSE;
  else if(ret && !gdome_str_equal(temp_str,gdome_str_mkref("lippo3")))
		fprintf(stderr,"\nElement::getAttributeNS(\"%s\",\"%s\"), wrong", attr_URI->str, attr_name->str), ret = FALSE;
	attr_name = gdome_str_mkref("XXXX");
  attr_URI = gdome_str_mkref("urn:cips.ciak.uk");
	temp_str = gdome_el_getAttributeNS(el, attr_URI, attr_name, &exc);
  if(temp_str != NULL)
		fprintf(stderr,"\nElement::getAttribute(\"%s\",\"%s\"), NOT NULL", attr_URI->str, attr_name->str), ret = FALSE;
	attr_name = gdome_str_mkref("CIPPO3");
  attr_URI = gdome_str_mkref("urn:xxxx.xxxx.xx");
	temp_str = gdome_el_getAttributeNS(el, attr_URI, attr_name, &exc);
  if(temp_str != NULL)
		fprintf(stderr,"\nElement::getAttribute(\"%s\",\"%s\"), NOT NULL", attr_URI->str, attr_name->str), ret = FALSE;
  dot();

	/* test Element::setAttribute */
	attr_name = gdome_str_mkref("NEWATTR");
	attr_value = gdome_str_mkref("newvalue");
	gdome_el_setAttribute(el, attr_name, attr_value, &exc);
	temp_str = gdome_el_getAttribute(el, attr_name, &exc);
  if(temp_str == NULL)
		fprintf(stderr,"\nElement::setAttribute(\"%s\",\"%s\"), NULL", attr_name->str, attr_value->str), ret = FALSE;
  else if(ret && !gdome_str_equal(attr_value, temp_str))
		fprintf(stderr,"\nElement::setAttribute(\"%s\",\"%s\"), wrong", attr_name->str, attr_value->str), ret = FALSE;
  dot();

	/* test Element::setAttributeNS */
	attr_name = gdome_str_mkref("myns:NEWATTR1");
	attr_value = gdome_str_mkref("newvalue1");
  attr_URI = gdome_str_mkref("urn:myns.casarini.org");
	gdome_el_setAttributeNS(el, attr_URI, attr_name, attr_value, &exc);
	attr_name = gdome_str_mkref("NEWATTR1");
	temp_str = gdome_el_getAttributeNS(el, attr_URI, attr_name, &exc);
  if(temp_str == NULL)
		fprintf(stderr,"\nElement::setAttributeNS(\"%s\",\"%s\",\"%s\"), NULL", attr_URI->str, attr_name->str, attr_value->str), ret = FALSE;
  else if(ret && !gdome_str_equal(attr_value, temp_str))
		fprintf(stderr,"\nElement::setAttributeNS(\"%s\",\"%s\",\"%s\"), wrong", attr_URI->str, attr_name->str, attr_value->str), ret = FALSE;

	/* test Element::removeAttribute */
	attr_name = gdome_str_mkref("FOO4");
	gdome_el_removeAttribute(el, attr_name, &exc);
	temp_str = gdome_el_getAttribute(el, attr_name, &exc);
  if(temp_str != NULL)
		fprintf(stderr,"\nElement::removeAttribute(\"%s\"), NOT NULL", attr_name->str), ret = FALSE;
  dot();

	/* test Element::removeAttributeNS */
	attr_name = gdome_str_mkref("CIPPO4");
  attr_URI = gdome_str_mkref("urn:cips.ciak.uk");
	gdome_el_removeAttributeNS(el, attr_URI, attr_name, &exc);
	temp_str = gdome_el_getAttributeNS(el, attr_URI, attr_name, &exc);
  if(temp_str != NULL)
		fprintf(stderr,"\nElement::removeAttributeNS(\"%s\",\"%s\"), NOT NULL", attr_URI->str,attr_name->str), ret = FALSE;
	dot();

	/* test Element::hasAttribute */
	attr_name = gdome_str_mkref("NEWATTR");
	if (!gdome_el_hasAttribute(el, attr_name, &exc))
		fprintf(stderr,"\nElement::hasAttrbute(\"%s\"), wrong", attr_name->str), ret = FALSE;
	attr_name = gdome_str_mkref("BOBOBO");
	if (gdome_el_hasAttribute(el, attr_name, &exc))
		fprintf(stderr,"\nElement::hasAttribute(\"%s\")2, wrong", attr_name->str), ret = FALSE;


	/* test Element::hasAttributeNS */
	attr_name = gdome_str_mkref("NEWATTR1");
  attr_URI = gdome_str_mkref("urn:myns.casarini.org");
	if (!gdome_el_hasAttributeNs(el, attr_URI, attr_name, &exc))
		fprintf(stderr,"\nElement::hasAttrbuteNS(\"%s\",\"%s\"), wrong", attr_URI->str, attr_name->str), ret = FALSE;
	attr_name = gdome_str_mkref("BOBOBO");
  attr_URI = gdome_str_mkref("urn:myns.casarini.org");
	if (gdome_el_hasAttributeNs(el, attr_URI, attr_name, &exc))
		fprintf(stderr,"\nElement::hasAttrbuteNS(\"%s\",\"%s\"), wrong", attr_URI->str, attr_name->str), ret = FALSE;
	attr_name = gdome_str_mkref("NEWATTR1");
  attr_URI = gdome_str_mkref("urn:myns.xxxx.xx");
	if (gdome_el_hasAttributeNs(el, attr_URI, attr_name, &exc))
		fprintf(stderr,"\nElement::hasAttrbuteNS(\"%s\",\"%s\"), wrong", attr_URI->str, attr_name->str), ret = FALSE;
  dot();


	printf("test_el\n");
  return ret;
}

int
main (int argc, char **argv)
{
	GdomeDOMImplementation *domImpl = NULL;
	GdomeDocument *domdoc = NULL;
  GdomeElement *el = NULL;
  GdomeException exc = 0;
  gboolean ret;


	domImpl = gdome_DOMImplementation_mkref();
  domdoc = gdome_DOMImplementation_parseFile (domImpl, "test-element.xml", &exc);

  el = gdome_doc_documentElement (domdoc, &exc);
  ret = test_el(el);

  gdome_el_unref (el, &exc);
  gdome_DOMImplementation_freeDoc(domImpl, domdoc, &exc);

	if(ret)
		return 0;
	else
		return -1;
}

